cdsaxs package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cdsaxs.simulations

Submodules
----------

cdsaxs.fitter module
--------------------

.. automodule:: cdsaxs.fitter
   :members:
   :undoc-members:
   :show-inheritance:

cdsaxs.residual module
----------------------

.. automodule:: cdsaxs.residual
   :members:
   :undoc-members:
   :show-inheritance: